@@ -17,10 +17,11 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
 
+#include <config.h>
+
+#include <gnome.h>
+#include <gtk/gtk.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
@@ -36,148 +37,106 @@
 #include "infoview.h"
 #include "procactions.h"
 #include "load-graph.h"
-#include "cellrenderer.h"
 #include "util.h"
 
-static void	cb_toggle_tree (GtkMenuItem *menuitem, gpointer data);
-static void	cb_toggle_threads (GtkMenuItem *menuitem, gpointer data);
+static void	cb_toggle_tree (GtkAction *action, gpointer data);
+static void	cb_toggle_threads (GtkAction *action, gpointer data);
 
-
-static GnomeUIInfo file1_menu_uiinfo[] =
+static const GtkActionEntry menu_entries[] =
 {
-	GNOMEUIINFO_MENU_QUIT_ITEM (cb_app_exit, NULL),
-	GNOMEUIINFO_END
+	{ "File", NULL, N_("_File") },
+	{ "Edit", NULL, N_("_Edit") },
+	{ "View", NULL, N_("_View") },
+	{ "Help", NULL, N_("_Help") },
+
+	{ "Quit", GTK_STOCK_QUIT, N_("_Quit"), "<control>Q",
+	  N_("Quit the program"), G_CALLBACK (cb_app_exit) },
+
+	{ "EndProcess", NULL, N_("End _Process"), "<control>E",
+	  N_("Force process to finish normally"), G_CALLBACK (cb_end_process) },
+	{ "KillProcess", NULL, N_("_Kill Process"), "<control>K",
+	  N_("Force process to finish immediately"), G_CALLBACK (cb_kill_process) },
+	{ "ChangePriority", NULL, N_("_Change Priority..."), "<control>R",
+	  N_("Change the order of priority of process"), G_CALLBACK (cb_renice) },
+	{ "Preferencies", GTK_STOCK_PREFERENCES, N_("Prefere_nces"), NULL,
+	  N_("Configure the application"), G_CALLBACK (cb_edit_preferences) },
+
+	{ "HideProcess", NULL, N_("_Hide Process"), "<control>H",
+	  N_("Hide process from list"), G_CALLBACK (cb_hide_process) },
+	{ "HiddenProcesses", NULL, N_("_Hidden Processes"), "<control>P",
+	  N_("Open the list of currently hidden processes"), G_CALLBACK (cb_show_hidden_processes) },
+	{ "MemoryMaps", NULL, N_("_Memory Maps"), "<control>M",
+	  N_("Open the memory maps associated with a process"), G_CALLBACK (cb_show_memory_maps) },
+	{ "OpenFiles", NULL, N_("Open _Files"), "<control>F",
+	  N_("View the files opened by a process"), G_CALLBACK (cb_show_open_files) },
+
+	{ "HelpContents", GTK_STOCK_HELP, N_("_Contents"), "F1",
+	  N_("Open the manual"), G_CALLBACK (cb_help_contents) },
+	{ "About", GTK_STOCK_ABOUT, N_("_About"), NULL,
+	  N_("About this application"), G_CALLBACK (cb_about) }
 };
 
-static GnomeUIInfo edit1_menu_uiinfo[] =
+static const GtkToggleActionEntry toggle_menu_entries[] =
 {
- 	{
- 	  GNOME_APP_UI_ITEM, N_("_Change Priority..."), N_("Change the importance (nice value) of a process"),
-	 cb_renice, NULL, NULL, 0, NULL,
-	 'r', GDK_CONTROL_MASK
-	},
-	{
-	 GNOME_APP_UI_ITEM, N_("_Hide Process"), N_("Hide a process"),
-	 cb_hide_process, NULL, NULL, 0, NULL,
-	 'h', GDK_CONTROL_MASK
-	}, 
-	GNOMEUIINFO_SEPARATOR,
-	{
-	 GNOME_APP_UI_ITEM, N_("End _Process"), N_("Force a process to finish."),
-	 cb_end_process, NULL, NULL, 0, NULL,
-	 'e', GDK_CONTROL_MASK
-	},
-	{
-	 GNOME_APP_UI_ITEM, N_("_Kill Process"), N_("Force a process to finish now."),
-	 cb_kill_process, NULL, NULL, 0, NULL,
-	 'k', GDK_CONTROL_MASK
-	},
-	GNOMEUIINFO_SEPARATOR,
-	{
-	 GNOME_APP_UI_ITEM, N_("_Hidden Processes"), 
-	 		    N_("View and edit your list of hidden processes"),
-	 cb_show_hidden_processes, NULL, NULL, 0, NULL,
-	 'p', GDK_CONTROL_MASK
-	},
-	GNOMEUIINFO_MENU_PREFERENCES_ITEM (cb_preferences_activate, NULL),
-	GNOMEUIINFO_END
+	{ "ShowDependencies", NULL, N_("_Dependencies"), "<control>D",
+	  N_("Show parent/child relationship between processes"),
+	  G_CALLBACK (cb_toggle_tree), TRUE },
+	{ "ShowThreads", NULL, N_("_Threads"), "<control>T",
+	  N_("Show each thread as a separate process"),
+	  G_CALLBACK (cb_toggle_threads), FALSE }
 };
 
-static GnomeUIInfo view1_menu_uiinfo[] =
-{
-	{
-	 GNOME_APP_UI_ITEM, N_("_Memory Maps"), N_("View the memory maps associated with a process"),
-	 cb_show_memory_maps, NULL, NULL, 0, NULL,
-	 'm', GDK_CONTROL_MASK
-	},
-	GNOMEUIINFO_SEPARATOR,
-	{
-	 GNOME_APP_UI_TOGGLEITEM, N_("Process _Dependencies"), N_("Display a tree showing process dependencies"),
-	 cb_toggle_tree, NULL, NULL, 0, NULL,
-	 'd', GDK_CONTROL_MASK
-	}, 
-	{
-	 GNOME_APP_UI_TOGGLEITEM, N_("_Threads"), N_("Display threads (subprocesses)"),
-	 cb_toggle_threads, NULL, NULL, 0, NULL,
-	 't', GDK_CONTROL_MASK
-	}, 
-	GNOMEUIINFO_END
-};
+static const char ui_info[] =
+"  <menubar name=\"MenuBar\">"
+"    <menu name=\"FileMenu\" action=\"File\">"
+"      <menuitem name=\"FileQuitMenu\" action=\"Quit\" />"
+"    </menu>"
+"    <menu name=\"EditMenu\" action=\"Edit\">"
+"      <menuitem name=\"EditEndProcessMenu\" action=\"EndProcess\" />"
+"      <menuitem name=\"EditKillProcessMenu\" action=\"KillProcess\" />"
+"      <separator />"
+"      <menuitem name=\"EditChangePriorityMenu\" action=\"ChangePriority\" />"
+"      <separator />"
+"      <menuitem name=\"EditPreferenciesMenu\" action=\"Preferencies\" />"
+"    </menu>"
+"    <menu name=\"ViewMenu\" action=\"View\">"
+"      <menuitem name=\"ViewDependenciesMenu\" action=\"ShowDependencies\" />"
+"      <menuitem name=\"ViewThreadsMenu\" action=\"ShowThreads\" />"
+"      <separator />"
+"      <menuitem name=\"ViewHideProcessMenu\" action=\"HideProcess\" />"
+"      <menuitem name=\"ViewHiddenProcessesMenu\" action=\"HiddenProcesses\" />"
+"      <separator />"
+"      <menuitem name=\"ViewMemoryMapsMenu\" action=\"MemoryMaps\" />"
+"      <menuitem name=\"ViewOpenFilesMenu\" action=\"OpenFiles\" />"
+"    </menu>"
+"    <menu name=\"HelpMenu\" action=\"Help\">"
+"      <menuitem name=\"HelpContentsMenu\" action=\"HelpContents\" />"
+"      <menuitem name=\"HelpAboutMenu\" action=\"About\" />"
+"    </menu>"
+"  </menubar>"
+"  <popup name=\"PopupMenu\" action=\"Popup\">"
+"    <menuitem action=\"EndProcess\" />"
+"    <menuitem action=\"KillProcess\" />"
+"    <separator />"
+"    <menuitem action=\"ChangePriority\" />"
+"    <separator />"
+"    <menuitem action=\"HideProcess\" />"
+"    <separator />"
+"    <menuitem action=\"MemoryMaps\" />"
+"    <menuitem action=\"OpenFiles\" />"
+"  </popup>";
 
-static GnomeUIInfo help1_menu_uiinfo[] =
-{
-	GNOMEUIINFO_HELP("gnome-system-monitor"),
-	GNOMEUIINFO_MENU_ABOUT_ITEM (cb_about_activate, NULL),
-	GNOMEUIINFO_END
-};
-
-static GnomeUIInfo menubar1_uiinfo[] =
-{
-	GNOMEUIINFO_MENU_FILE_TREE (file1_menu_uiinfo),
-	GNOMEUIINFO_MENU_EDIT_TREE (edit1_menu_uiinfo),
-	GNOMEUIINFO_MENU_VIEW_TREE (view1_menu_uiinfo),
-	GNOMEUIINFO_MENU_HELP_TREE (help1_menu_uiinfo),
-	GNOMEUIINFO_END
-};
-
-static GnomeUIInfo popup_menu_uiinfo[] =
-{
-	{
- 	  GNOME_APP_UI_ITEM, N_("_Change Priority..."), N_("Change the importance (nice value) of a process"),
-	 popup_menu_renice, NULL, NULL, 0, NULL,
-	 0, 0
-	},
-	{
- 	  GNOME_APP_UI_ITEM, N_("_Memory Maps"), N_("View the memory maps associated with a process"),
-	 popup_menu_show_memory_maps, NULL, NULL, 0, NULL,
-	 0, 0
-	},
-	GNOMEUIINFO_SEPARATOR,
-	{
- 	  GNOME_APP_UI_ITEM, N_("_Hide Process"), N_("Hide a process"),
-	 popup_menu_hide_process, NULL, NULL, 0, NULL,
-	 0, 0
-	},
-	GNOMEUIINFO_SEPARATOR,
-	{
- 	  GNOME_APP_UI_ITEM, N_("_End Process"), N_("Force a process to finish"),
-	 popup_menu_end_process, NULL, NULL, 0, NULL,
-	 0, 0
-	},
-	{
- 	  GNOME_APP_UI_ITEM, N_("_Kill Process"), N_("Force a process to finish now"),
-	 popup_menu_kill_process, NULL, NULL, 0, NULL,
-	 0, 0
-	},
-	GNOMEUIINFO_END
-};
-
-
-static GtkWidget *infolabel = NULL;
-static GtkWidget *endprocessbutton = NULL;
-static GtkWidget *popup_menu = NULL;
-static GtkWidget *sys_pane = NULL;
-
-
-gint
-get_sys_pane_pos (void)
-{
-	return GTK_PANED (sys_pane)->child1_size;
-}
 
 static GtkWidget *
 create_proc_view (ProcData *procdata)
 {
-	GtkWidget *vbox1;
+	GtkWidget *vbox1, *vbox2;
 	GtkWidget *hbox1;
-	GtkWidget *search_label;
-	GtkWidget *search_entry;
 	GtkWidget *proc_combo;
 	GtkWidget *scrolled;
-	GtkWidget *infobox;
 	GtkWidget *label;
 	GtkWidget *hbox2;
-	GtkWidget *infobutton;
+	char* string;
 
 	vbox1 = gtk_vbox_new (FALSE, 18);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox1), 12);
@@ -185,28 +144,24 @@ create_proc_view (ProcData *procdata)
 	hbox1 = gtk_hbox_new (FALSE, 12);
 	gtk_box_pack_start (GTK_BOX (vbox1), hbox1, FALSE, FALSE, 0);
 
-	search_label = gtk_label_new_with_mnemonic (_("Sea_rch:"));
-	gtk_box_pack_start (GTK_BOX (hbox1), search_label, FALSE, FALSE, 0);
-	
-	search_entry = gtk_entry_new ();
-	gtk_box_pack_start (GTK_BOX (hbox1), search_entry, FALSE, FALSE, 0);
-	g_signal_connect (G_OBJECT (search_entry), "activate",
-			  G_CALLBACK (cb_search), procdata);
-	gtk_label_set_mnemonic_widget (GTK_LABEL (search_label), search_entry);
+	string = make_loadavg_string ();
+	procdata->loadavg = gtk_label_new (string);
+	g_free (string);
+	gtk_box_pack_start (GTK_BOX (hbox1), procdata->loadavg, FALSE, FALSE, 0);
 
 	proc_combo = gtk_combo_box_new_text ();
 	gtk_box_pack_end (GTK_BOX (hbox1), proc_combo, FALSE, FALSE, 0);
 
-	gtk_combo_box_insert_text (GTK_COMBO_BOX (proc_combo), ALL_PROCESSES, _("All Processes"));
-	gtk_combo_box_insert_text (GTK_COMBO_BOX (proc_combo), MY_PROCESSES, _("My Processes"));
-	gtk_combo_box_insert_text (GTK_COMBO_BOX (proc_combo), ACTIVE_PROCESSES, _("Active Processes"));
+	gtk_combo_box_insert_text (GTK_COMBO_BOX (proc_combo), ALL_PROCESSES, _("All processes"));
+	gtk_combo_box_insert_text (GTK_COMBO_BOX (proc_combo), MY_PROCESSES, _("My processes"));
+	gtk_combo_box_insert_text (GTK_COMBO_BOX (proc_combo), ACTIVE_PROCESSES, _("Active processes"));
 
 	gtk_combo_box_set_active (GTK_COMBO_BOX (proc_combo), procdata->config.whose_process);
 
 	g_signal_connect (G_OBJECT (proc_combo), "changed",
 			  G_CALLBACK (cb_proc_combo_changed), procdata);
 
-  	label = gtk_label_new_with_mnemonic (_("Vie_w:"));
+  	label = gtk_label_new_with_mnemonic (_("Sho_w:"));
   	gtk_label_set_mnemonic_widget (GTK_LABEL (label), proc_combo);
 	gtk_box_pack_end (GTK_BOX (hbox1), label, FALSE, FALSE, 0);
 
@@ -222,31 +177,26 @@ create_proc_view (ProcData *procdata)
 	
 	gtk_widget_show_all (scrolled);
 	
-	infobox = infoview_create (procdata);
-	gtk_box_pack_start (GTK_BOX (vbox1), infobox, FALSE, FALSE, 0);
-
 	hbox2 = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (vbox1), hbox2, FALSE, FALSE, 0);
-	
-	endprocessbutton = gtk_button_new_with_mnemonic (_("End _Process"));
-  	gtk_box_pack_end (GTK_BOX (hbox2), endprocessbutton, FALSE, FALSE, 0);
-	g_signal_connect (G_OBJECT (endprocessbutton), "clicked",
-			  G_CALLBACK (cb_end_process_button_pressed), procdata);
 
-	infolabel = gtk_label_new_with_mnemonic (_("More _Info"));
-	infobutton = gtk_button_new ();
-	gtk_container_add (GTK_CONTAINER (infobutton), infolabel);
-	gtk_box_pack_start (GTK_BOX (hbox2), infobutton, FALSE, FALSE, 0);
-	g_signal_connect (G_OBJECT (infobutton), "clicked",
-			  G_CALLBACK (cb_info_button_pressed), procdata);
+	infoview_create (procdata);
+	gtk_box_pack_start (GTK_BOX (hbox2), procdata->infoview.expander, FALSE, FALSE, 0);
+	gtk_expander_set_expanded (GTK_EXPANDER(procdata->infoview.expander),
+				   procdata->config.show_more_info);
+	gtk_widget_show (procdata->infoview.expander);
+	
+	vbox2 = gtk_vbox_new (FALSE, 0);
+	gtk_box_pack_end (GTK_BOX (hbox2), vbox2, FALSE, FALSE, 0);
+	procdata->endprocessbutton = gtk_button_new_with_mnemonic (_("End _Process"));
+	gtk_box_pack_end (GTK_BOX (vbox2), procdata->endprocessbutton, FALSE, FALSE, 0);
+	g_signal_connect (G_OBJECT (procdata->endprocessbutton), "clicked",
+			  G_CALLBACK (cb_end_process_button_pressed), procdata);
 	
 	gtk_widget_show_all (hbox2);
 	
 	/* create popup_menu */
- 	popup_menu = gtk_menu_new ();
- 	gnome_app_fill_menu_with_data (GTK_MENU_SHELL (popup_menu), popup_menu_uiinfo,
-  			               NULL, TRUE, 0, procdata);
-	gtk_widget_show (popup_menu);
+ 	procdata->popup_menu = gtk_ui_manager_get_widget (procdata->uimanager, "/PopupMenu");
 
         return vbox1;
 }
@@ -256,39 +206,29 @@ sort_bytes (GtkTreeModel *model, GtkTreeIter *itera, GtkTreeIter *iterb, gpointe
 {
 	int col = GPOINTER_TO_INT (data);
 	float btotal1, btotal2, bfree1, bfree2;
-	float a, b;
-	
-	btotal1 = btotal2 = bfree1 = bfree2 = 0.0;
-	gtk_tree_model_get (model, itera, 7, &btotal1, 8, &bfree1, -1);
-	gtk_tree_model_get (model, iterb, 7, &btotal2, 8, &bfree2, -1);
+
+	btotal1 = btotal2 = bfree1 = bfree2 = 0.0f;
+	gtk_tree_model_get (model, itera, 8, &btotal1, 9, &bfree1, -1);
+	gtk_tree_model_get (model, iterb, 8, &btotal2, 9, &bfree2, -1);
 
 	switch (col)
 	{
-		case 4: 
-			a = btotal1;
-			b = btotal2;
-			break;
-		case 5: 
-			a = btotal1 - bfree1;
-			b = btotal2 - bfree2;
-			break;
-		case 6: 
-			a = bfree1;
-			b = bfree2;
-			break;
-		default:
-			a = 0;
-			b = 0;
-	}
+		case 4:
+			return PROCMAN_CMP(btotal1, btotal2);
 
-	if (a > b)
-		return -1;
-	else if (a < b)
-		return 1;
-	return 0;	
+		case 5:
+			return PROCMAN_CMP(bfree1, bfree2);
+
+		case 6:
+			return PROCMAN_CMP(btotal1 - bfree1, btotal2 - bfree2);
+
+		default:
+			g_assert_not_reached();
+			return 0;
+	}
 }
 
-static GtkWidget *
+GtkWidget *
 make_title_label (const char *text)
 {
   GtkWidget *label;
@@ -298,7 +238,7 @@ make_title_label (const char *text)
   label = gtk_label_new (full);
   g_free (full);
 
-  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+  gtk_misc_set_alignment (GTK_MISC (label), 0.0f, 0.5f);
   gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 
   return label;
@@ -312,45 +252,163 @@ cpu_size_request (GtkWidget *box, GtkRequisition *req, ProcData *procdata)
 		MAX(req->width, procdata->cpu_label_fixed_width);
 }
 
-static GtkWidget *
-create_sys_view (ProcData *procdata)
+
+
+
+static GtkWidget*
+create_disk_view (ProcData *procdata)
 {
-	GtkWidget *vbox, *hbox;
-	GtkWidget *vpane;
-	GtkWidget *cpu_box, *mem_box, *disk_box;
-	GtkWidget *cpu_hbox, *mem_hbox, *disk_hbox;
-	GtkWidget *cpu_graph_box, *mem_graph_box;
-	GtkWidget *label,*cpu_label, *spacer;
-	GtkWidget *table;
-	GtkWidget *color_picker;
+	GtkWidget *disk_box, *disk_hbox;
+	GtkWidget *label, *spacer;
 	GtkWidget *scrolled;
 	GtkWidget *disk_tree;
 	GtkTreeStore *model;
 	GtkTreeViewColumn *col;
 	GtkCellRenderer *cell;
-	GtkSizeGroup *sizegroup;
+	gint i;
 
-	static const gchar *titles[5] = {
-	  N_("Name"),
+	static const gchar *titles[] = {
+	  N_("Device"),
 	  N_("Directory"),
 	  N_("Type"),
 	  N_("Total"),
+	  N_("Free"),
 	  N_("Used"),
 	};
 
+	PROCMAN_GETTEXT_ARRAY_INIT(titles);
+
+	disk_box = gtk_vbox_new (FALSE, 6);
+
+	gtk_container_set_border_width (GTK_CONTAINER (disk_box), 6);
+
+	label = make_title_label (_("Devices"));
+	gtk_box_pack_start (GTK_BOX (disk_box), label, FALSE, FALSE, 0);
+
+	disk_hbox = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (disk_box), disk_hbox, TRUE, TRUE, 0);
+
+	spacer = gtk_label_new ("    ");
+	gtk_box_pack_start (GTK_BOX (disk_hbox), spacer, FALSE, FALSE, 0);
+
+	scrolled = gtk_scrolled_window_new (NULL, NULL);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled), 
+					GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled),
+                                             GTK_SHADOW_IN);
+
+	gtk_box_pack_start (GTK_BOX (disk_hbox), scrolled, TRUE, TRUE, 0);
+
+
+	model = gtk_tree_store_new (10,
+				    GDK_TYPE_PIXBUF,
+				    G_TYPE_STRING, /* device name */
+				    G_TYPE_STRING, /* directory */
+				    G_TYPE_STRING, /* type */
+				    G_TYPE_STRING, /* total */
+				    G_TYPE_STRING, /* free */
+				    G_TYPE_STRING, /* used */
+				    G_TYPE_FLOAT,
+				    G_TYPE_FLOAT,
+				    G_TYPE_FLOAT);
+
+	disk_tree = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
+	procdata->disk_list = disk_tree;
+	gtk_container_add (GTK_CONTAINER (scrolled), disk_tree);
+  	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (disk_tree), TRUE);
+  	g_object_unref (G_OBJECT (model));
+  	
+ 	col = gtk_tree_view_column_new ();
+  	cell = gtk_cell_renderer_pixbuf_new ();
+	gtk_tree_view_column_pack_start (col, cell, FALSE);
+	gtk_tree_view_column_set_attributes (col, cell,
+					     "pixbuf", 0,
+					     NULL);
+		
+	cell = gtk_cell_renderer_text_new ();
+	gtk_tree_view_column_pack_start (col, cell, FALSE);
+	gtk_tree_view_column_set_attributes (col, cell,
+					     "text", 1,
+					     NULL);
+	gtk_tree_view_column_set_title (col, titles[0]);
+	gtk_tree_view_column_set_sort_column_id (col, 1);
+	gtk_tree_view_column_set_resizable (col, TRUE);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (disk_tree), col);
+								
+  	for (i = 1; i < 5	; i++) {
+  		cell = gtk_cell_renderer_text_new ();
+  		col = gtk_tree_view_column_new_with_attributes (titles[i],
+						    		cell,
+						     		"text", i + 1,
+						     		NULL);
+		gtk_tree_view_column_set_resizable (col, TRUE);
+		gtk_tree_view_column_set_sort_column_id (col, i + 1);
+		gtk_tree_view_append_column (GTK_TREE_VIEW (disk_tree), col);
+	}
+	
+	col = gtk_tree_view_column_new ();	
+
+	cell = gtk_cell_renderer_text_new ();
+	gtk_tree_view_column_pack_start (col, cell, FALSE);
+	gtk_tree_view_column_set_attributes (col, cell,
+					     "text", 6,
+					     NULL);
+	gtk_tree_view_column_set_title (col, titles[5]);
+		
+	
+	cell = gtk_cell_renderer_progress_new ();
+	gtk_tree_view_column_pack_start (col, cell, TRUE);
+	gtk_tree_view_column_set_attributes (col, cell,
+					     "value", 7,
+					     NULL);
+	
+	gtk_tree_view_append_column (GTK_TREE_VIEW (disk_tree), col);
+	gtk_tree_view_column_set_resizable (col, TRUE);
+	gtk_tree_view_column_set_sort_column_id (col, 6);
+	
+	gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (model),
+					 4, sort_bytes, GINT_TO_POINTER (4), NULL);
+	gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (model),
+					 5, sort_bytes, GINT_TO_POINTER (5), NULL);
+	gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (model),
+					 6, sort_bytes, GINT_TO_POINTER (6), NULL);
+
+
+	gtk_widget_show_all (disk_box);
+  	
+  	procman_get_tree_state (procdata->client, disk_tree, "/apps/procman/disktreenew");
+  	
+  	cb_update_disks (procdata);
+  	procdata->disk_timeout = gtk_timeout_add (procdata->config.disks_update_interval,
+  						  cb_update_disks, procdata);
+
+
+	return disk_box;
+}
+
+
+
+
+
+
+
+static GtkWidget *
+create_sys_view (ProcData *procdata)
+{
+	GtkWidget *vbox, *hbox;
+	GtkWidget *cpu_box, *mem_box;
+	GtkWidget *cpu_hbox, *mem_hbox;
+	GtkWidget *cpu_graph_box, *mem_graph_box;
+	GtkWidget *label,*cpu_label, *spacer;
+	GtkWidget *table;
+	GtkWidget *color_picker;
+	GtkSizeGroup *sizegroup;
+	GdkColor color;
 	LoadGraph *cpu_graph, *mem_graph;
 	gint i;
 
-	PROCMAN_GETTEXT_ARRAY_INIT(titles);
-	
-	vpane = gtk_vpaned_new ();
-	sys_pane = vpane;
-	gtk_paned_set_position (GTK_PANED (vpane), procdata->config.pane_pos);
-	
-	gtk_container_set_border_width (GTK_CONTAINER (vpane), 6);
 
 	vbox = gtk_vbox_new (FALSE, 18);
-	gtk_paned_pack1 (GTK_PANED (vpane), vbox, TRUE, FALSE);
 
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
 
@@ -389,17 +447,22 @@ create_sys_view (ProcData *procdata)
 		gtk_size_group_add_widget (sizegroup, temp_hbox);
 		g_signal_connect (G_OBJECT (temp_hbox), "size_request",
 					 G_CALLBACK (cpu_size_request), procdata);
-		
-		color_picker = gnome_color_picker_new ();
-		gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (color_picker), 
-				    cpu_graph->colors[2+i].red,
-				    cpu_graph->colors[2+i].green,
-				    cpu_graph->colors[2+i].blue, 0);
+
+		color.red   = cpu_graph->colors[2+i].red;
+		color.green = cpu_graph->colors[2+i].green;
+		color.blue  = cpu_graph->colors[2+i].blue;
+		color_picker = gtk_color_button_new_with_color (&color);
+
 		g_signal_connect (G_OBJECT (color_picker), "color_set",
 			    G_CALLBACK (cb_cpu_color_changed), GINT_TO_POINTER (i));
 		gtk_box_pack_start (GTK_BOX (temp_hbox), color_picker, FALSE, FALSE, 0);
 		
-		text = g_strdup_printf (_("CPU%d:"), i+1);
+		if(procdata->config.num_cpus == 1) {
+			text = g_strdup (_("CPU:"));
+		}
+		else {
+			text = g_strdup_printf (_("CPU%d:"), i+1);
+		}
 		label = gtk_label_new (text);
 		gtk_box_pack_start (GTK_BOX (temp_hbox), label, FALSE, FALSE, 0);
 		g_free (text);
@@ -442,16 +505,16 @@ create_sys_view (ProcData *procdata)
 	gtk_box_pack_start (GTK_BOX (mem_graph_box), table, 
 			    FALSE, FALSE, 0);
 
-	color_picker = gnome_color_picker_new ();
-	gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (color_picker), 
-				    mem_graph->colors[2].red,
-				    mem_graph->colors[2].green,
-				    mem_graph->colors[2].blue, 0);
+
+	color.red   = mem_graph->colors[2].red;
+	color.green = mem_graph->colors[2].green;
+	color.blue  = mem_graph->colors[2].blue;
+	color_picker = gtk_color_button_new_with_color (&color);
 	g_signal_connect (G_OBJECT (color_picker), "color_set",
 			    G_CALLBACK (cb_mem_color_changed), procdata);
 	gtk_table_attach (GTK_TABLE (table), color_picker, 0, 1, 0, 1, 0, 0, 0, 0);
 	
-	label = gtk_label_new (_("Used memory:"));
+	label = gtk_label_new (_("User memory:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label, 1, 2, 0, 1, GTK_FILL, 0, 0, 0);
 	
@@ -474,11 +537,10 @@ create_sys_view (ProcData *procdata)
 	gtk_table_attach (GTK_TABLE (table), mem_graph->mempercent_label, 5, 6, 0, 1, 
 			  GTK_FILL, 0, 0, 0);
 			  
-	color_picker = gnome_color_picker_new ();
-	gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (color_picker), 
-				    mem_graph->colors[3].red,
-				    mem_graph->colors[3].green,
-				    mem_graph->colors[3].blue, 0);
+	color.red   = mem_graph->colors[3].red;
+	color.green = mem_graph->colors[3].green;
+	color.blue  = mem_graph->colors[3].blue;
+	color_picker = gtk_color_button_new_with_color (&color);
 	g_signal_connect (G_OBJECT (color_picker), "color_set",
 			    G_CALLBACK (cb_swap_color_changed), procdata);
 	gtk_table_attach (GTK_TABLE (table), color_picker, 0, 1, 1, 2, 0, 0, 0, 0);
@@ -509,279 +571,186 @@ create_sys_view (ProcData *procdata)
 	procdata->mem_graph = mem_graph;
 	gtk_widget_show_all (vbox);
 
-
-	/*****************************************/
-
-	disk_box = gtk_vbox_new (FALSE, 6);
-
-	gtk_container_set_border_width (GTK_CONTAINER (disk_box), 6);
-
-	gtk_paned_pack2 (GTK_PANED (vpane), disk_box, TRUE, TRUE);
-
-	label = make_title_label (_("Devices"));
-	gtk_box_pack_start (GTK_BOX (disk_box), label, FALSE, FALSE, 0);
-
-	disk_hbox = gtk_hbox_new (FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (disk_box), disk_hbox, TRUE, TRUE, 0);
-
-	spacer = gtk_label_new ("    ");
-	gtk_box_pack_start (GTK_BOX (disk_hbox), spacer, FALSE, FALSE, 0);
-
-	scrolled = gtk_scrolled_window_new (NULL, NULL);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled), 
-					GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled),
-                                             GTK_SHADOW_IN);
-
-	gtk_box_pack_start (GTK_BOX (disk_hbox), scrolled, TRUE, TRUE, 0);
-
-	 
-	model = gtk_tree_store_new (9, GDK_TYPE_PIXBUF, G_TYPE_STRING, 
-					   G_TYPE_STRING, G_TYPE_STRING,
-				       G_TYPE_STRING, G_TYPE_STRING,
-					G_TYPE_FLOAT, G_TYPE_FLOAT, G_TYPE_FLOAT);
-				       
-	disk_tree = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
-	procdata->disk_list = disk_tree;
-	gtk_container_add (GTK_CONTAINER (scrolled), disk_tree);
-  	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (disk_tree), TRUE);
-  	g_object_unref (G_OBJECT (model));
-  	
- 	col = gtk_tree_view_column_new ();
-  	cell = gtk_cell_renderer_pixbuf_new ();
-	gtk_tree_view_column_pack_start (col, cell, FALSE);
-	gtk_tree_view_column_set_attributes (col, cell,
-					     "pixbuf", 0,
-					     NULL);
-		
-	cell = gtk_cell_renderer_text_new ();
-	gtk_tree_view_column_pack_start (col, cell, FALSE);
-	gtk_tree_view_column_set_attributes (col, cell,
-					     "text", 1,
-					     NULL);
-	gtk_tree_view_column_set_title (col, titles[0]);
-	gtk_tree_view_column_set_sort_column_id (col, 1);
-	gtk_tree_view_column_set_resizable (col, TRUE);
-	gtk_tree_view_append_column (GTK_TREE_VIEW (disk_tree), col);
-								
-  	for (i = 1; i < 4	; i++) {
-  		cell = gtk_cell_renderer_text_new ();
-  		col = gtk_tree_view_column_new_with_attributes (titles[i],
-						    		cell,
-						     		"text", i + 1,
-						     		NULL);
-		gtk_tree_view_column_set_resizable (col, TRUE);
-		gtk_tree_view_column_set_sort_column_id (col, i + 1);
-		gtk_tree_view_append_column (GTK_TREE_VIEW (disk_tree), col);
-	}
-	
-	col = gtk_tree_view_column_new ();	
-
-	cell = gtk_cell_renderer_text_new ();
-	gtk_tree_view_column_pack_start (col, cell, FALSE);
-	gtk_tree_view_column_set_attributes (col, cell,
-					     "text", 5,
-					     NULL);
-	gtk_tree_view_column_set_title (col, titles[4]);
-		
-	
-	cell = procman_cell_renderer_progress_new ();
-	gtk_tree_view_column_pack_start (col, cell, TRUE);
-	gtk_tree_view_column_set_attributes (col, cell,
-					     "value", 6,
-					     NULL);
-	
-	gtk_tree_view_append_column (GTK_TREE_VIEW (disk_tree), col);
-	gtk_tree_view_column_set_resizable (col, TRUE);
-	gtk_tree_view_column_set_sort_column_id (col, 5);
-	
-	gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (model),
-					 4, sort_bytes, GINT_TO_POINTER (4), NULL);
-	gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (model),
-					 5, sort_bytes, GINT_TO_POINTER (5), NULL);
-	
-	gtk_widget_show_all (disk_box);
-  	
-  	procman_get_tree_state (procdata->client, disk_tree, "/apps/procman/disktreenew");
-  	
-  	cb_update_disks (procdata);
-  	procdata->disk_timeout = gtk_timeout_add (procdata->config.disks_update_interval,
-  						  cb_update_disks, procdata);
-
-
-	return vpane;
+	return vbox;
 }
 
-GtkWidget*
+static void
+menu_item_select_cb (GtkMenuItem *proxy,
+                     ProcData *procdata)
+{
+	GtkAction *action;
+	char *message;
+
+	action = g_object_get_data (G_OBJECT (proxy),  "gtk-action");
+	g_return_if_fail (action != NULL);
+
+	g_object_get (G_OBJECT (action), "tooltip", &message, NULL);
+	if (message)
+	{
+		gtk_statusbar_push (GTK_STATUSBAR (procdata->statusbar),
+				    procdata->tip_message_cid, message);
+		g_free (message);
+	}
+}
+
+static void
+menu_item_deselect_cb (GtkMenuItem *proxy,
+                       ProcData *procdata)
+{
+	gtk_statusbar_pop (GTK_STATUSBAR (procdata->statusbar),
+			   procdata->tip_message_cid);
+}
+
+static void
+connect_proxy_cb (GtkUIManager *manager,
+                  GtkAction *action,
+                  GtkWidget *proxy,
+                  ProcData *procdata)
+{
+	if (GTK_IS_MENU_ITEM (proxy)) {
+		g_signal_connect (proxy, "select",
+				  G_CALLBACK (menu_item_select_cb), procdata);
+		g_signal_connect (proxy, "deselect",
+				  G_CALLBACK (menu_item_deselect_cb), procdata);
+	}
+}
+
+static void
+disconnect_proxy_cb (GtkUIManager *manager,
+                     GtkAction *action,
+                     GtkWidget *proxy,
+                     ProcData *procdata)
+{
+	if (GTK_IS_MENU_ITEM (proxy)) {
+		g_signal_handlers_disconnect_by_func
+			(proxy, G_CALLBACK (menu_item_select_cb), procdata);
+		g_signal_handlers_disconnect_by_func
+			(proxy, G_CALLBACK (menu_item_deselect_cb), procdata);
+	}
+}
+
+void
 create_main_window (ProcData *procdata)
 {
 	gint width, height;
 	GtkWidget *app;
+	GtkAction *action;
+	GtkWidget *menubar;
+	GtkWidget *main_box;
 	GtkWidget *notebook;
-	GtkWidget *tab_label1, *tab_label2;
+	GtkWidget *tab_label1, *tab_label2, *tab_label3;
 	GtkWidget *vbox1;
-	GtkWidget *sys_box;
-	GtkWidget *appbar1;
-	
+	GtkWidget *sys_box, *devices_box;
+
 	app = gnome_app_new ("procman", _("System Monitor"));
+
+	main_box = gtk_vbox_new (FALSE, 0);
+	gnome_app_set_contents (GNOME_APP (app), main_box);
+	gtk_widget_show (main_box);
 	
 	width = procdata->config.width;
 	height = procdata->config.height;
 	gtk_window_set_default_size (GTK_WINDOW (app), width, height);
 	gtk_window_set_resizable (GTK_WINDOW (app), TRUE);
 	
-	gnome_app_create_menus_with_data (GNOME_APP (app), menubar1_uiinfo, procdata);
-	
+	/* create the menubar */
+	procdata->uimanager = gtk_ui_manager_new ();
+
+	/* show tooltips in the statusbar */
+	g_signal_connect (procdata->uimanager, "connect_proxy",
+			  G_CALLBACK (connect_proxy_cb), procdata);
+	g_signal_connect (procdata->uimanager, "disconnect_proxy",
+			 G_CALLBACK (disconnect_proxy_cb), procdata);
+
+	gtk_window_add_accel_group (GTK_WINDOW (app),
+				    gtk_ui_manager_get_accel_group (procdata->uimanager));
+
+	if (!gtk_ui_manager_add_ui_from_string (procdata->uimanager,
+	                                        ui_info,
+	                                        -1,
+	                                        NULL)) {
+		g_error("building menus failed");
+	}
+
+	procdata->action_group = gtk_action_group_new ("ProcmanActions");
+	gtk_action_group_set_translation_domain (procdata->action_group, NULL);
+	gtk_action_group_add_actions (procdata->action_group,
+	                              menu_entries,
+	                              G_N_ELEMENTS (menu_entries),
+	                              procdata);
+	gtk_action_group_add_toggle_actions (procdata->action_group,
+	                                     toggle_menu_entries,
+	                                     G_N_ELEMENTS (toggle_menu_entries),
+	                                     procdata);
+
+	gtk_ui_manager_insert_action_group (procdata->uimanager,
+	                                    procdata->action_group,
+	                                    0);
+
+	menubar = gtk_ui_manager_get_widget (procdata->uimanager, "/MenuBar");
+	gtk_box_pack_start (GTK_BOX (main_box), menubar, FALSE, FALSE, 0);
+
+
+	/* create the main notebook */
 	notebook = gtk_notebook_new ();
-	
+  	gtk_box_pack_start (GTK_BOX (main_box), 
+	                    notebook, 
+	                    TRUE, 
+	                    TRUE, 
+	                    0);
+	gtk_widget_show (notebook);
+
 	vbox1 = create_proc_view (procdata);
-	tab_label1 = gtk_label_new (_("Process Listing"));
+	gtk_widget_show (vbox1);
+	tab_label1 = gtk_label_new (_("Processes"));
 	gtk_widget_show (tab_label1);
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox1, tab_label1);
 	
 	sys_box = create_sys_view (procdata);
 	gtk_widget_show (sys_box);
-	tab_label2 = gtk_label_new (_("Resource Monitor"));
+	tab_label2 = gtk_label_new (_("Resources"));
 	gtk_widget_show (tab_label2);
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), sys_box, tab_label2);
-	
-	appbar1 = gtk_statusbar_new();
-	gnome_app_set_statusbar (GNOME_APP (app), appbar1);
-	
+
+	devices_box = create_disk_view (procdata);
+	gtk_widget_show(devices_box);
+	tab_label3 = gtk_label_new (_("Devices"));
+	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), devices_box, tab_label3);
+
+	g_signal_connect (G_OBJECT (notebook), "switch-page",
+			  G_CALLBACK (cb_switch_page), procdata);
+	g_signal_connect (G_OBJECT (notebook), "change-current-page",
+			  G_CALLBACK (cb_change_current_page), procdata);
+
+
+	gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), procdata->config.current_tab);
+	cb_change_current_page (GTK_NOTEBOOK (notebook), procdata->config.current_tab, procdata);
 	g_signal_connect (G_OBJECT (app), "delete_event",
                           G_CALLBACK (cb_app_delete),
                           procdata);
-	
-	gnome_app_install_menu_hints (GNOME_APP (app), menubar1_uiinfo);
-		    
-	g_signal_connect (G_OBJECT (notebook), "switch-page",
-			    G_CALLBACK (cb_switch_page), procdata);
 
-	if (procdata->config.current_tab == 0)
-		procdata->timeout = gtk_timeout_add (procdata->config.update_interval,
-			 		     cb_timeout, procdata);
-	else {
-		load_graph_start (procdata->cpu_graph);
-		load_graph_start (procdata->mem_graph);
-	}
-	 	
-	gtk_widget_show (vbox1);
-	gnome_app_set_contents (GNOME_APP (app), notebook);
-	gtk_widget_show (notebook);
 
-	update_sensitivity (procdata, FALSE);
-	
-	/* We cheat and force it to set up the labels */
- 	procdata->config.show_more_info = !procdata->config.show_more_info;
- 	toggle_infoview (procdata);
+	/* create the statusbar */
+	procdata->statusbar = gtk_statusbar_new();
+	gnome_app_set_statusbar (GNOME_APP (app), procdata->statusbar);
+	procdata->tip_message_cid = gtk_statusbar_get_context_id
+		(GTK_STATUSBAR (procdata->statusbar), "tip_message");
 
- 	gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), procdata->config.current_tab);
- 	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (view1_menu_uiinfo[2].widget),
-							  procdata->config.show_tree);
- 	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (view1_menu_uiinfo[3].widget),
-							  procdata->config.show_threads);
-	
- 	return app;
 
-}
+	action = gtk_action_group_get_action (procdata->action_group, "ShowDependencies");
+	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
+				      procdata->config.show_tree);
 
-GtkWidget*
-create_simple_view_dialog (ProcData *procdata)
-{
-#if 0
-	GtkWidget *app = NULL;
-	GtkWidget *main_vbox;
-	GtkWidget *scrolled;
-	GtkWidget *vbox;
-	GtkWidget *hbox;
-	GtkWidget *label;
-	GtkWidget *button;
-	GtkWidget *frame;
-	guint key;
-	
-	app = gnome_dialog_new (_("Application Manager"), GNOME_STOCK_BUTTON_CANCEL, NULL);
-	gtk_window_set_policy (GTK_WINDOW (app), FALSE, TRUE, FALSE);
-	gtk_window_set_default_size (GTK_WINDOW (app), 350, 425);
-	
-	main_vbox = GNOME_DIALOG (app)->vbox;
-	
-	frame = gtk_frame_new (_("Running Applications"));
-	gtk_container_set_border_width (GTK_CONTAINER (frame), GNOME_PAD_SMALL);
-	gtk_box_pack_start (GTK_BOX (main_vbox), frame, TRUE, TRUE, 0);
-	
-	vbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
-	gtk_container_set_border_width (GTK_CONTAINER (vbox), GNOME_PAD_SMALL);
-	gtk_container_add (GTK_CONTAINER (frame), vbox);
-	
-	scrolled = proctable_new (procdata);
-	if (!scrolled)
-		return NULL;
-	gtk_box_pack_start (GTK_BOX (vbox), scrolled, TRUE, TRUE, 0);
-	
-	hbox = gtk_hbox_new (FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
-	
-	button = gtk_button_new ();
-	endprocessbutton = button;
-  	label = gtk_label_new (NULL);
-	key = gtk_label_parse_uline (GTK_LABEL (label), _("_Close Application"));
-	gtk_widget_add_accelerator (button, "clicked",
-				    accel,
-				    key,
-				    GDK_MOD1_MASK,
-				    0);
-	gtk_container_add (GTK_CONTAINER (button), label);
-	gtk_box_pack_end (GTK_BOX (hbox), button, FALSE, FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (button), GNOME_PAD_SMALL);
-	gtk_misc_set_padding (GTK_MISC (GTK_BIN (button)->child), 
-			      GNOME_PAD_SMALL, 1);
-	g_signal_connect (G_OBJECT (button), "clicked",
-			    G_CALLBACK (cb_end_process_button_pressed), procdata);
+	action = gtk_action_group_get_action (procdata->action_group, "ShowThreads");
+	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
+				      procdata->config.show_threads);
 
-	g_signal_connect (G_OBJECT (app), "close",
-			    G_CALLBACK (cb_close_simple_dialog), procdata);
-	g_signal_connect (G_OBJECT (procdata->tree), "cursor_activated",
-			    G_CALLBACK (cb_table_selected), procdata);
-			    
-	/* Makes sure everything that should be insensitive is at start */
-	gtk_signal_emit_by_name (G_OBJECT (procdata->tree), "cursor_activated",
-				 -1, NULL);
-				 
-	procdata->timeout = gtk_timeout_add (procdata->config.update_interval,
-			 		     cb_timeout, procdata);
-			 		    
-	
-			    
-	gtk_widget_show_all (main_vbox);
-	gtk_widget_show (app);
-	
-	return app;
-#endif
-	return NULL;
+
+	procdata->app = app;
 }
 
 void
-toggle_infoview (ProcData *procdata)
-{
-	if (procdata->config.show_more_info)
-	{
-		gtk_widget_hide (procdata->infobox);
-		gtk_label_set_text_with_mnemonic (GTK_LABEL (infolabel),
-						  _("More _Info >>"));
-	}
-	else
-	{
-		infoview_update (procdata);
-		gtk_widget_show_all (procdata->infobox);
-		gtk_label_set_text_with_mnemonic (GTK_LABEL (infolabel),
-						  _("<< Less _Info"));
-	}
-
-	procdata->config.show_more_info = ! procdata->config.show_more_info;
-}
-
-void
-do_popup_menu (ProcData *data, GdkEventButton *event)
+do_popup_menu (ProcData *procdata, GdkEventButton *event)
 {
 	gint button;
 	gint event_time;
@@ -795,54 +764,63 @@ do_popup_menu (ProcData *data, GdkEventButton *event)
 		event_time = gtk_get_current_event_time ();
 	}
 
-	gtk_menu_popup (GTK_MENU (popup_menu), NULL, NULL,
+	gtk_menu_popup (GTK_MENU (procdata->popup_menu), NULL, NULL,
 			NULL, NULL, button, event_time);
 }
 
 void
 update_sensitivity (ProcData *data, gboolean sensitivity)
 {
-	gtk_widget_set_sensitive (endprocessbutton, sensitivity);
-	
-	if (!data->config.simple_view) {
-		gtk_widget_set_sensitive (data->infobox, sensitivity);
-		gtk_widget_set_sensitive (edit1_menu_uiinfo[0].widget, sensitivity);
-		gtk_widget_set_sensitive (edit1_menu_uiinfo[1].widget, sensitivity);
-		gtk_widget_set_sensitive (view1_menu_uiinfo[0].widget, sensitivity);
-		gtk_widget_set_sensitive (edit1_menu_uiinfo[2].widget, sensitivity);
-		gtk_widget_set_sensitive (edit1_menu_uiinfo[3].widget, sensitivity);
-		gtk_widget_set_sensitive (edit1_menu_uiinfo[4].widget, sensitivity);
+	GtkAction *action;
+
+	if(data->endprocessbutton) {
+		/* avoid error on startup if endprocessbutton
+		   has not been built yet */
+		gtk_widget_set_sensitive (data->endprocessbutton, sensitivity);
 	}
+
+	gtk_widget_set_sensitive (data->infoview.box, sensitivity);
+
+	action = gtk_action_group_get_action (data->action_group, "EndProcess");
+	gtk_action_set_sensitive (action, sensitivity);
+	action = gtk_action_group_get_action (data->action_group, "KillProcess");
+	gtk_action_set_sensitive (action, sensitivity);
+	action = gtk_action_group_get_action (data->action_group, "ChangePriority");
+	gtk_action_set_sensitive (action, sensitivity);
+	action = gtk_action_group_get_action (data->action_group, "HideProcess");
+	gtk_action_set_sensitive (action, sensitivity);
+	action = gtk_action_group_get_action (data->action_group, "HiddenProcesses");
+	gtk_action_set_sensitive (action, sensitivity);
+	action = gtk_action_group_get_action (data->action_group, "MemoryMaps");
+	gtk_action_set_sensitive (action, sensitivity);
+	action = gtk_action_group_get_action (data->action_group, "OpenFiles");
+	gtk_action_set_sensitive (action, sensitivity);
 }
 
 static void		
-cb_toggle_tree (GtkMenuItem *menuitem, gpointer data)
+cb_toggle_tree (GtkAction *action, gpointer data)
 {
 	ProcData *procdata = data;
-	GtkCheckMenuItem *menu = GTK_CHECK_MENU_ITEM (view1_menu_uiinfo[2].widget);
 	GConfClient *client = procdata->client;
 	gboolean show;
-	
-	show = gtk_check_menu_item_get_active (menu);
+
+	show = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
 	if (show == procdata->config.show_tree)
 		return;
-		
+
 	gconf_client_set_bool (client, "/apps/procman/show_tree", show, NULL);
-	
 }
 
 static void		
-cb_toggle_threads (GtkMenuItem *menuitem, gpointer data)
+cb_toggle_threads (GtkAction *action, gpointer data)
 {
 	ProcData *procdata = data;
-	GtkCheckMenuItem *menu = GTK_CHECK_MENU_ITEM (view1_menu_uiinfo[3].widget);
 	GConfClient *client = procdata->client;
 	gboolean show;
-	
-	show = gtk_check_menu_item_get_active (menu);
+
+	show = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
 	if (show == procdata->config.show_threads)
 		return;
-		
+
 	gconf_client_set_bool (client, "/apps/procman/show_threads", show, NULL);
-	
 }
